import com.github.jengelman.gradle.plugins.shadow.tasks.ShadowJar
import org.jetbrains.kotlin.gradle.tasks.KotlinCompile
import org.gradle.internal.os.OperatingSystem

plugins {
    application
    java
    kotlin("jvm") version "1.3.30"
    id("com.github.johnrengelman.shadow") version "4.0.4"
}

group = "rakorium"
version = "1.0"

repositories {
    mavenCentral()
}

val lwjglVersion = "3.2.1"
val jomlVersion = "1.9.14"

val lwjglNatives = when (OperatingSystem.current()) {
    OperatingSystem.LINUX -> "natives-linux"
    OperatingSystem.WINDOWS -> "natives-windows"
    OperatingSystem.MAC_OS -> "natives-macos"
    else -> throw Error("Unrecognized or unsupported Operating system. Please set \"lwjglNatives\" manually")
} // */

dependencies {
    compile(kotlin("stdlib-jdk8"))
    testCompile("junit", "junit", "4.12")

    compile("org.joml", "joml", jomlVersion)

    implementation("org.lwjgl", "lwjgl", lwjglVersion)
    implementation("org.lwjgl", "lwjgl-glfw", lwjglVersion)
    implementation("org.lwjgl", "lwjgl-opengl", lwjglVersion)
    implementation("org.lwjgl", "lwjgl-stb", lwjglVersion)
    runtimeOnly("org.lwjgl", "lwjgl", lwjglVersion, classifier = lwjglNatives)
    runtimeOnly("org.lwjgl", "lwjgl-glfw", lwjglVersion, classifier = lwjglNatives)
    runtimeOnly("org.lwjgl", "lwjgl-opengl", lwjglVersion, classifier = lwjglNatives)
    runtimeOnly("org.lwjgl", "lwjgl-stb", lwjglVersion, classifier = lwjglNatives)


    //*
    // Binaries for all architectures in one jar
    runtimeOnly("org.lwjgl", "lwjgl", lwjglVersion, classifier = "natives-windows")
    runtimeOnly("org.lwjgl", "lwjgl-glfw", lwjglVersion, classifier = "natives-windows")
    runtimeOnly("org.lwjgl", "lwjgl-opengl", lwjglVersion, classifier = "natives-windows")
    runtimeOnly("org.lwjgl", "lwjgl-stb", lwjglVersion, classifier = "natives-windows")

    runtimeOnly("org.lwjgl", "lwjgl", lwjglVersion, classifier = "natives-linux")
    runtimeOnly("org.lwjgl", "lwjgl-glfw", lwjglVersion, classifier = "natives-linux")
    runtimeOnly("org.lwjgl", "lwjgl-opengl", lwjglVersion, classifier = "natives-linux")
    runtimeOnly("org.lwjgl", "lwjgl-stb", lwjglVersion, classifier = "natives-linux")

    runtimeOnly("org.lwjgl", "lwjgl", lwjglVersion, classifier = "natives-macos")
    runtimeOnly("org.lwjgl", "lwjgl-glfw", lwjglVersion, classifier = "natives-macos")
    runtimeOnly("org.lwjgl", "lwjgl-opengl", lwjglVersion, classifier = "natives-macos")
    runtimeOnly("org.lwjgl", "lwjgl-stb", lwjglVersion, classifier = "natives-macos")
    // */

    testImplementation("org.junit.jupiter:junit-jupiter-api:5.3.1")
    testRuntimeOnly("org.junit.jupiter:junit-jupiter-engine:5.3.1")
}



application {
    mainClassName = "moonlander.MainKt"
}

configure<JavaPluginConvention> {
    sourceCompatibility = JavaVersion.VERSION_1_8
}

tasks.withType<KotlinCompile> {
    kotlinOptions.jvmTarget = "1.8"
}

tasks.withType<ShadowJar> {
    baseName = "MoonLander"
    classifier = ""
    version = ""
}

tasks.withType<Test> {
	useJUnitPlatform()
}