package moonlander.views

import moonlander.models.Ground
import org.joml.Matrix4f
import org.joml.Vector4f
import kotlin.math.ceil
import kotlin.math.floor


/**
 * Render the ground (by selecting individual buckets and rendering them).
 */
class GroundView(val ground: Ground) {

	private val groundElements = HashMap<Int, GroundElementView>()

	fun render(viewMatrix: Matrix4f) {
		// Detect left / right border of viewport
		val inverseViewMatrix = Matrix4f()
		viewMatrix.invert(inverseViewMatrix)
		val unitVector = Vector4f(-1.05f, 0f, 0f, 1f)
		unitVector.mul(inverseViewMatrix)
		val leftBorder = unitVector.x
		unitVector.set(1.05f, 0f, 0f, 1f)
		unitVector.mul(inverseViewMatrix)
		val rightBorder = unitVector.x

		// convert to element indices
		val leftBucket = floor(leftBorder / ground.bucketWidth).toInt()
		val rightBucket = ceil(rightBorder / ground.bucketWidth).toInt()

		// ensure all ground elements are loaded, then render
		for (i in leftBucket..rightBucket) {
			val bucketElement = groundElements.getOrPut(i) { GroundElementView(ground, i) }
			bucketElement.render(viewMatrix)
		}
	}

	fun reset() {
		groundElements.clear()
	}
}