package moonlander.views

import moonlander.Controller
import moonlander.models.MoonLander
import org.joml.Matrix4f
import kotlin.math.PI


/**
 * Renders the moon lander at the correct position, and delegates rendering of its engines.
 */
class MoonLanderView(controller: Controller, val lander: MoonLander) : ImageObject("/me-lander-1.png") {

	val mainEngine = RocketEngine(controller, Matrix4f().translate(0f, -1.5f, 0f).scale(0.75f))
	val leftSideEngine =
		RocketEngine(controller, Matrix4f().translate(.75f, .12f, 0f).scale(0.4f).rotate(PI.toFloat() * 0.35f, 0f, 0f, 1f))
	val rightSideEngine =
		RocketEngine(controller, Matrix4f().translate(-.75f, .12f, 0f).scale(0.4f).rotate(PI.toFloat() * -0.35f, 0f, 0f, 1f))

	override fun render(viewMatrix: Matrix4f) {
		modelMatrix.identity()
			.translate(lander.position.x, lander.position.y, 0f)
			.scale(lander.size)
			.mul(lander.orientation)

		mainEngine.render(lander.engineFiring, modelMatrix, viewMatrix)
		leftSideEngine.render(lander.sideEngineFiring > 0, modelMatrix, viewMatrix)
		rightSideEngine.render(lander.sideEngineFiring < 0, modelMatrix, viewMatrix)

		super.render(viewMatrix)
	}

}