package moonlander.views

import moonlander.Controller
import org.joml.Matrix4f


/**
 * A rocket engine renderer (based on sprite renderer.
 */
class RocketEngine(val controller: Controller, val relativeModelMatrix: Matrix4f) :
	SpriteRenderer("/rocketburner_sprite_512px_x_581px_per_frame.png", 3, 6) {

	private var lastTickWasBurning: Boolean = false
	private var lastTimeChanged = Double.NEGATIVE_INFINITY

	fun render(isBurning: Boolean, outerModelMatrix: Matrix4f, viewMatrix: Matrix4f) {
		if (isBurning != lastTickWasBurning || controller.totalTime < lastTimeChanged) {
			lastTimeChanged = controller.totalTime
			lastTickWasBurning = isBurning
		}
		val tpos = ((controller.totalTime - lastTimeChanged) * 15).toInt()
		if (tpos < cols) {
			// start/stop burning
			submitBuffer(if (isBurning) 0 else 1, tpos % cols)
		} else if (!isBurning) {
			// engine is off
			return;
		} else {
			submitBuffer(2, tpos % cols)
		}

		outerModelMatrix.mul(relativeModelMatrix, modelMatrix)
		super.render(viewMatrix)
	}
}