package moonlander.views.hud

import moonlander.Controller
import moonlander.format
import moonlander.views.text.FontRenderer
import org.joml.Matrix4f
import java.awt.Font


/**
 * Top left statistics
 */
class StatsHUDView(val controller: Controller) : FontRenderer(font, true, 120) {
	companion object {
		val font = readFont("/RobotoMono-Regular.ttf", 60)

		fun readFont(resource: String, size: Int): Font {
			StatsHUDView::class.java.getResourceAsStream(resource).use {
				return Font.createFont(Font.TRUETYPE_FONT, it).deriveFont(size.toFloat()).deriveFont(Font.BOLD)
			}
		}
	}

	override fun render(viewMatrix: Matrix4f) {
		prepareTextBuffer(
			"""
			|Flight time: ${controller.totalTime.format(6, 2)} s
			|Height:      ${controller.landerHeight().format(5, 1)}  m
			|Orientation: ${controller.moonLander.orientationAngle().format(5, 1)}  °
			|Speed:       ${controller.moonLander.speed.length().format(5, 1)}  m/s
			|Fuel:        ${controller.moonLander.fuel.format(5, 1)}  l""".trimMargin(),
			20f, -380f
		)
		super.render(viewMatrix)
	}
}